from setuptools import setup

setup(name='ccwutilities',
      version='1.1',
      description='CCW Utilities',
      author='Michael van der Veeke',
      author_email='mva@ccw.vic.edu.au',
      url='https://ccw.vic.edu.au',
     )